# Gilly Utilities

Gilly Utilities is a bespoke extension package used in the Python programming language. There is no specific theme for this package, but rather extends some of the functionality of Python. Alot of these modules are based on using NumPy, SciPy, Pandas and Statsmodels. 

I adore you to have a look around at the code and find something that you'll find useful! If needs be, fork this repository and use Gilly Utilites are your very own python package!

Citing Gilly Utilities couldn't be easier. How about a DOI?

[![DOI](https://zenodo.org/badge/158018663.svg)](https://zenodo.org/badge/latestdoi/158018663)

# Python 3 Compatability

Gilly utilities works for python 3 now. Most functions work, but not all